@@ -1,6 +1,6 @@
 package AnyEvent::HTTP::LWP::UserAgent;
 {
-  $AnyEvent::HTTP::LWP::UserAgent::VERSION = '0.09';
+  $AnyEvent::HTTP::LWP::UserAgent::VERSION = '0.10';
 }
 
 use strict;
@@ -41,7 +41,7 @@ sub simple_request_async {
     my $out_req;
     my $content = '';
     my $fh;
-    if(!ref($arg) && length($arg)) {
+    if(!ref($arg) && defined($arg) && length($arg)) {
         open $fh, '>', $arg or $cv->croak("Can't write to '$arg': $!");
         binmode $fh;
         $args->{on_body} = sub {
@@ -132,7 +132,7 @@ sub simple_request_async {
         $out_req->content($d) if defined $d;
         close($fh) or $cv->croak("Can't write to '$arg': $!") if defined ($fh);
 
-        if(length $d) {
+        if(defined($d) && length($d)) {
             # from LWP::Protocol
             my %skip_h;
             for my $h ($self->handlers('response_data', $out_req)) {
@@ -421,7 +421,7 @@ AnyEvent::HTTP::LWP::UserAgent - LWP::UserAgent interface but works using AnyEve
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
